import React, { useMemo } from 'react';
import { DndContext, closestCenter } from '@dnd-kit/core';
import { SortableContext, arrayMove } from '@dnd-kit/sortable';
import DnDItem from './DnDItem';
const DnDList = ({
  items,
  setItems,
  templateItem = () => {},
  ...props
}) => {
  const itemsFormatted = useMemo(() => {
    items.forEach(i => {
      if (i.id == null) {
        i.id = Date.now() * Math.random();
      }
    });
    return items;
  }, [items]);
  const onDragEnd = event => {
    const {
      active,
      over
    } = event;
    if (active.id !== over.id) {
      const oldIndex = itemsFormatted.findIndex(i => i.id === active.id);
      const newIndex = itemsFormatted.findIndex(i => i.id === over.id);
      setItems(arrayMove(items, oldIndex, newIndex));
    }
  };
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(DndContext, {
    onDragEnd: onDragEnd,
    collisionDetection: closestCenter
  }, /*#__PURE__*/React.createElement(SortableContext, {
    items: items
  }, items.map((item, index) => /*#__PURE__*/React.createElement(DnDItem, {
    key: index,
    item: item,
    index: index,
    templateItem: templateItem
  })))));
};
export default DnDList;